@@ -3,6 +3,9 @@
 #include <math.h>
 #include <stdlib.h>
 #include <complex.h>
+
+
+#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
 #include <numpy/arrayobject.h>
 
 
@@ -99,9 +102,9 @@ static PyObject *atomic_displacements(PyObject *self, PyObject *arg, PyObject *k
     static char *kwlist[] = {"trajectory", "positions", "cell", NULL};
     if (!PyArg_ParseTupleAndKeywords(arg, keywords, "OOO", kwlist,  &Trajectory_obj, &Positions_obj, &Cell_obj))  return NULL;
 
-    PyObject *Trajectory_array = PyArray_FROM_OTF(Trajectory_obj, NPY_CDOUBLE, NPY_IN_ARRAY);
-    PyObject *Positions_array = PyArray_FROM_OTF(Positions_obj, NPY_DOUBLE, NPY_IN_ARRAY);
-    PyObject *Cell_array = PyArray_FROM_OTF(Cell_obj, NPY_DOUBLE, NPY_IN_ARRAY);
+    PyObject *Trajectory_array = PyArray_FROM_OTF(Trajectory_obj, NPY_CDOUBLE, NPY_ARRAY_IN_ARRAY);
+    PyObject *Positions_array = PyArray_FROM_OTF(Positions_obj, NPY_DOUBLE, NPY_ARRAY_IN_ARRAY);
+    PyObject *Cell_array = PyArray_FROM_OTF(Cell_obj, NPY_DOUBLE, NPY_ARRAY_IN_ARRAY);
 
     if (Cell_array == NULL || Trajectory_array == NULL) {
          Py_XDECREF(Cell_array);
@@ -112,11 +115,11 @@ static PyObject *atomic_displacements(PyObject *self, PyObject *arg, PyObject *k
 
 
 //  double _Complex *Cell           = (double _Complex*)PyArray_DATA(Cell_array);
-    _Dcomplex *Trajectory     = (_Dcomplex*)PyArray_DATA(Trajectory_array);
-    double *Positions               = (double*)PyArray_DATA(Positions_array);
+    _Dcomplex *Trajectory     = (_Dcomplex*)PyArray_DATA((PyArrayObject *)Trajectory_array);
+    double *Positions               = (double*)PyArray_DATA((PyArrayObject *)Positions_array);
 
-    int NumberOfData       = (int)PyArray_DIM(Trajectory_array, 0);
-    int NumberOfDimensions = (int)PyArray_DIM(Cell_array, 0);
+    int NumberOfData       = (int)PyArray_DIM((PyArrayObject *)Trajectory_array, 0);
+    int NumberOfDimensions = (int)PyArray_DIM((PyArrayObject *)Cell_array, 0);
 
 //  Create new Numpy array to store the result
     _Dcomplex **Displacement;
@@ -196,11 +199,18 @@ static PyObject *atomic_displacements(PyObject *self, PyObject *arg, PyObject *k
 
 static _Dcomplex **pymatrix_to_c_array_complex(PyArrayObject *array)  {
 
-      long n=(*array).dimensions[0];
-      long m=(*array).dimensions[1];
+      //long n=(*array).dimensions[0];
+      //long m=(*array).dimensions[1];
+
+      long n = PyArray_DIMS(array)[0];
+      long m = PyArray_DIMS(array)[1];
+
       _Dcomplex ** c = malloc(n*sizeof(_Dcomplex));
 
-      _Dcomplex *a = (_Dcomplex *) (*array).data;  /* pointer to array data as double _Complex */
+      //_Dcomplex *a = (_Dcomplex *) (*array).data;  /* pointer to array data as double _Complex */
+
+      _Dcomplex *a = (_Dcomplex *) PyArray_DATA(array);
+
       for ( int i=0; i<n; i++)  {
           c[i]=a+i*m;
       }
@@ -211,12 +221,15 @@ static _Dcomplex **pymatrix_to_c_array_complex(PyArrayObject *array)  {
 
 static double  **pymatrix_to_c_array_real(PyArrayObject *array)  {
 
-      long n=(*array).dimensions[0];
-      long m=(*array).dimensions[1];
+      // long n=(*array).dimensions[0];
+      // long m=(*array).dimensions[1];
+      long n = PyArray_DIMS(array)[0];
+      long m = PyArray_DIMS(array)[1];
       //PyObject *transpose_array = PyArray_Transpose(array, dims);
 
       double  ** c = malloc(n*sizeof(double));
-      double  *a = (double  *) (*array).data;
+      // double  *a = (double  *) (*array).data;
+      double *a = (double *) PyArray_DATA(array);
 
       for ( int i=0; i<n; i++)  {
           double  *b = malloc(m*sizeof(double));
