@@ -3,12 +3,16 @@
 #include <math.h>
 #include <stdlib.h>
 #include <complex.h>
-#include <numpy/arrayobject.h>
 
 #if defined(ENABLE_OPENMP)
 #include <omp.h>
 #endif
 
+
+#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
+#include <numpy/arrayobject.h>
+
+
 #undef I
 
 // Cross compatibility mingw - gcc
@@ -107,8 +111,8 @@ static PyObject* MaximumEntropyMethod (PyObject* self, PyObject *arg, PyObject *
     static char *kwlist[] = {"frequency", "velocity", "time_step", "coefficients", NULL};
     if (!PyArg_ParseTupleAndKeywords(arg, keywords, "OOd|i", kwlist, &frequency_obj, &velocity_obj, &TimeStep, &NumberOfCoefficients))  return NULL;
 
-    PyObject *velocity_array = PyArray_FROM_OTF(velocity_obj, NPY_CDOUBLE, NPY_IN_ARRAY);
-    PyObject *frequency_array = PyArray_FROM_OTF(frequency_obj, NPY_DOUBLE, NPY_IN_ARRAY);
+    PyObject *velocity_array = PyArray_FROM_OTF( velocity_obj, NPY_CDOUBLE, NPY_ARRAY_IN_ARRAY);
+    PyObject *frequency_array = PyArray_FROM_OTF( frequency_obj, NPY_DOUBLE, NPY_ARRAY_IN_ARRAY);
 
     if (velocity_array == NULL || frequency_array == NULL ) {
         Py_XDECREF(velocity_array);
@@ -116,10 +120,10 @@ static PyObject* MaximumEntropyMethod (PyObject* self, PyObject *arg, PyObject *
         return NULL;
     }
 
-    _Dcomplex  *Velocity = (_Dcomplex *)PyArray_DATA(velocity_array);
-    double *Frequency    = (double*)PyArray_DATA(frequency_array);
-    int    NumberOfData = (int)PyArray_DIM(velocity_array, 0);
-    int     NumberOfFrequencies = (int)PyArray_DIM(frequency_array, 0);
+    _Dcomplex  *Velocity = (_Dcomplex *)PyArray_DATA((PyArrayObject *)velocity_array);
+    double *Frequency    = (double*)PyArray_DATA((PyArrayObject *)frequency_array);
+    int    NumberOfData = (int)PyArray_DIM((PyArrayObject *)velocity_array, 0);
+    int     NumberOfFrequencies = (int)PyArray_DIM((PyArrayObject *)frequency_array, 0);
 
 
     //Create new numpy array for storing result
