@@ -1,4 +1,4 @@
-__version__ = '1.17.13'
+__version__ = '1.18.0'
 import dynaphopy.projection as projection
 import dynaphopy.parameters as parameters
 import dynaphopy.interface.phonopy_link as pho_interface
@@ -13,7 +13,10 @@ import matplotlib.pyplot as plt
 
 
 from dynaphopy.power_spectrum import power_spectrum_functions
-from scipy import integrate
+try:
+    from scipy.integrate import simps
+except ImportError:
+    from scipy.integrate import simpson as simps
 
 
 class Quasiparticle:
@@ -856,7 +859,7 @@ class Quasiparticle:
         mem_coefficient_scan_analysis(self.get_vq(), self.dynamic, self.parameters)
 
     def phonon_individual_analysis(self):
-        print("Peak analysis analysis")
+        print("Peak analysis")
 
         fitting.phonon_fitting_analysis(self.get_power_spectrum_phonon(),
                                         self.parameters.frequency_range,
@@ -883,6 +886,7 @@ class Quasiparticle:
                                                            mesh=self.parameters.mesh_phonopy,
                                                            freq_min=self.get_frequency_range()[0],
                                                            freq_max=self.get_frequency_range()[-1],
+                                                           freq_pitch=self.parameters.spectrum_resolution,
                                                            projected_on_atom=self.parameters.project_on_atom,
                                                            NAC=self.parameters.use_NAC)
 
@@ -894,6 +898,7 @@ class Quasiparticle:
                                                              mesh=self.parameters.mesh_phonopy,
                                                              freq_min=self.get_frequency_range()[0],
                                                              freq_max=self.get_frequency_range()[-1],
+                                                             freq_pitch=self.parameters.spectrum_resolution,
                                                              force_constants=self._renormalized_force_constants,
                                                              projected_on_atom=self.parameters.project_on_atom,
                                                              NAC=self.parameters.use_NAC)
@@ -910,7 +915,7 @@ class Quasiparticle:
         # plt.legend()
         plt.show()
 
-        total_integral = integrate.simps(self.get_power_spectrum_full(), x=self.get_frequency_range())
+        total_integral = simps(self.get_power_spectrum_full(), x=self.get_frequency_range())
         print("Total Area (Kinetic energy <K>): {0} eV".format(total_integral))
 
     def plot_power_spectrum_wave_vector(self):
@@ -920,7 +925,7 @@ class Quasiparticle:
         plt.ylabel('eV * ps')
         plt.axhline(y=0, color='k', ls='dashed')
         plt.show()
-        total_integral = integrate.simps(self.get_power_spectrum_wave_vector(), x=self.get_frequency_range())
+        total_integral = simps(self.get_power_spectrum_wave_vector(), x=self.get_frequency_range())
         print("Total Area (Kinetic energy <K>): {0} eV".format(total_integral))
 
     def plot_power_spectrum_phonon(self):
@@ -1031,14 +1036,14 @@ class Quasiparticle:
         reading.write_curve_to_file(self.get_frequency_range(),
                                     self.get_power_spectrum_full()[None].T,
                                     file_name)
-        total_integral = integrate.simps(self.get_power_spectrum_full(), x=self.get_frequency_range())
+        total_integral = simps(self.get_power_spectrum_full(), x=self.get_frequency_range())
         print("Total Area (Kinetic energy <K>): {0} eV".format(total_integral))
 
     def write_power_spectrum_wave_vector(self, file_name):
         reading.write_curve_to_file(self.get_frequency_range(),
                                     self.get_power_spectrum_wave_vector()[None].T,
                                     file_name)
-        total_integral = integrate.simps(self.get_power_spectrum_wave_vector(), x=self.get_frequency_range())
+        total_integral = simps(self.get_power_spectrum_wave_vector(), x=self.get_frequency_range())
         print("Total Area (Kinetic energy <K>): {0} eV".format(total_integral))
 
     def write_power_spectrum_phonon(self, file_name):
@@ -1205,19 +1210,47 @@ class Quasiparticle:
 
         return self._renormalized_force_constants
 
+    def get_commensurate_points_properties(self):
+
+        #  Decide the size of the supercell to use to calculate the renormalized force constants
+        if self._parameters.use_MD_cell_commensurate:
+            fc_supercell = np.diag(self.dynamic.get_supercell_matrix())
+        else:
+            fc_supercell = self.dynamic.structure.get_supercell_phonon()
+
+        com_points = pho_interface.get_commensurate_points(self.dynamic.structure,
+                                                           fc_supercell)
+
+        group_velocity_list = []
+        q_points_list = []
+        for i, reduced_q_vector in enumerate(com_points):
+
+            gv = pho_interface.obtain_phonopy_group_velocity(self.dynamic.structure,
+                                                             reduced_q_vector,
+                                                             force_constants=self.get_renormalized_force_constants())
+
+            group_velocity_list.append(gv)
+            q_points_list.append(reduced_q_vector)
+
+        return {'group_velocity': group_velocity_list,
+                'q_points': q_points_list,
+                'fc_supercell': fc_supercell}
+
     def write_renormalized_constants(self, filename="FORCE_CONSTANTS"):
         force_constants = self.get_renormalized_force_constants()
         pho_interface.save_force_constants_to_file(force_constants, filename)
 
-    def write_quasiparticles_data(self, filename="quasiparticles_data.yaml"):
+    def write_quasiparticles_data(self, filename="quasiparticles_data.yaml", with_extra=False):
         quasiparticle_data = self.get_commensurate_points_data()
+        if with_extra:
+            quasiparticle_data.update(self.get_commensurate_points_properties())
         reading.save_quasiparticle_data_to_file(quasiparticle_data, filename)
 
     def write_mesh_data(self, file_name='mesh_data.yaml'):
         mesh_data = self.get_mesh_frequencies_and_linewidths()
         reading.save_mesh_data_to_yaml_file(mesh_data, file_name)
 
-    def get_thermal_properties(self, force_constants=None):
+    def get_thermal_properties(self, force_constants=None, normalize_dos=False):
 
         temperature = self.get_temperature()
 
@@ -1225,16 +1258,25 @@ class Quasiparticle:
                                                        mesh=self.parameters.mesh_phonopy,
                                                        freq_min=0.01,
                                                        freq_max=self.get_frequency_range()[-1],
+                                                       freq_pitch=self.parameters.spectrum_resolution,
                                                        force_constants=force_constants,
                                                        projected_on_atom=self.parameters.project_on_atom,
                                                        NAC=self.parameters.use_NAC)
 
+        integration = simps(phonopy_dos[1], x=phonopy_dos[0]) / (
+                self.dynamic.structure.get_number_of_atoms() *
+                self.dynamic.structure.get_number_of_dimensions())
+
+        if normalize_dos:
+            phonopy_dos[1] /= integration
+            integration = 1.0
+            if self.parameters.project_on_atom > -1:
+                phonopy_dos[1] /= self.dynamic.structure.get_number_of_primitive_atoms()
+                integration /= self.dynamic.structure.get_number_of_primitive_atoms()
+
         free_energy = thm.get_free_energy(temperature, phonopy_dos[0], phonopy_dos[1])
         entropy = thm.get_entropy(temperature, phonopy_dos[0], phonopy_dos[1])
         c_v = thm.get_cv(temperature, phonopy_dos[0], phonopy_dos[1])
-        integration = integrate.simps(phonopy_dos[1], x=phonopy_dos[0]) / (
-            self.dynamic.structure.get_number_of_atoms() *
-            self.dynamic.structure.get_number_of_dimensions())
         total_energy = thm.get_total_energy(temperature, phonopy_dos[0], phonopy_dos[1])
 
         if force_constants is not None:
@@ -1243,6 +1285,7 @@ class Quasiparticle:
                                                              mesh=self.parameters.mesh_phonopy,
                                                              freq_min=0.01,
                                                              freq_max=self.get_frequency_range()[-1],
+                                                             freq_pitch=self.parameters.spectrum_resolution,
                                                              projected_on_atom=self.parameters.project_on_atom,
                                                              NAC=self.parameters.use_NAC)
 
@@ -1275,23 +1318,25 @@ class Quasiparticle:
                                                                                       NAC=self.parameters.use_NAC)
 
             print('\nThermal properties per unit cell ({0:.2f} K) [From phonopy (Reference)]\n'
-                  '----------------------------------------------'.format(temperature))
-            print('                               Harmonic    Quasiparticle\n')
-            print('Free energy (not corrected):   {0:.4f}       {3:.4f}     KJ/mol\n'
-                  'Entropy:                       {1:.4f}       {4:.4f}     J/K/mol\n'
-                  'Cv:                            {2:.4f}       {5:.4f}     J/K/mol\n'.format(
+                  '-----------------------------------------------------------------'.format(temperature))
+            print('                                   Harmonic   Quasiparticle\n')
+            print('Free energy (not corrected):   {0:12.4f}  {3:12.4f}   KJ/mol\n'
+                  'Entropy:                       {1:12.4f}  {4:12.4f}   J/K/mol\n'
+                  'Cv:                            {2:12.4f}  {5:12.4f}   J/K/mol\n'.format(
                 *(harmonic_properties + renormalized_properties)))
 
-        harmonic_properties = self.get_thermal_properties()
-        renormalized_properties = self.get_thermal_properties(force_constants=self.get_renormalized_force_constants())
+        harmonic_properties = self.get_thermal_properties(normalize_dos=normalize_dos)
+        renormalized_properties = self.get_thermal_properties(force_constants=self.get_renormalized_force_constants(),
+                                                              normalize_dos=normalize_dos)
         frequency_range = self.get_frequency_range()
+        resolution = frequency_range[1] - frequency_range[0]
 
         if from_power_spectrum:
             normalization = np.prod(self.dynamic.get_supercell_matrix())
 
             power_spectrum_dos = thm.get_dos(temperature, frequency_range, self.get_power_spectrum_full(),
                                              normalization)
-            integration = integrate.simps(power_spectrum_dos, x=frequency_range) / (
+            integration = simps(power_spectrum_dos, x=frequency_range) / (
                 self.dynamic.structure.get_number_of_atoms() *
                 self.dynamic.structure.get_number_of_dimensions())
 
@@ -1308,8 +1353,8 @@ class Quasiparticle:
             total_energy = thm.get_total_energy(temperature, frequency_range, power_spectrum_dos)
 
             power_spectrum_properties = [free_energy, entropy, c_v, total_energy, integration]
-            print('\nThermal properties per unit cell ({0:.2f} K) [From DoS]\n'
-                  '----------------------------------------------'.format(temperature))
+            print('\nThermal properties per unit cell ({0:.2f} K) [From DoS (resolution {1}) ]\n'
+                  '-----------------------------------------------------------------'.format(temperature, resolution))
             print('                             Harmonic   Quasiparticle   Power spectrum\n')
             print('Free energy   (KJ/mol): {0:12.4f}  {5:12.4f}  {10:12.4f}\n'
                   'Entropy      (J/K/mol): {1:12.4f}  {6:12.4f}  {11:12.4f}\n'
@@ -1323,8 +1368,8 @@ class Quasiparticle:
                 plt.axhline(y=0, color='k', ls='dashed')
 
         else:
-            print('\nThermal properties per unit cell ({0:.2f} K) [From DoS]\n'
-                  '----------------------------------------------'.format(temperature))
+            print('\nThermal properties per unit cell ({0:.2f} K) [From DoS (resolution {1})]\n'
+                  '-----------------------------------------------------------------'.format(temperature, resolution))
             print('                            Harmonic    Quasiparticle\n')
             print('Free energy   (KJ/mol): {0:12.4f}  {5:12.4f}\n'
                   'Entropy      (J/K/mol): {1:12.4f}  {6:12.4f}\n'
